#!/bin/bash -e

export WORKSPACE=`pwd`
export OS_VERSION="ubuntu15.10"
export ARCHIVE="${TOOLCHAIN_VERSION}-${OS_VERSION}.tar.gz"
export PACKAGE="swift-nightly"

export SWIFT_SOURCE_ROOT="${WORKSPACE}"
export SWIFT_BUILD_ROOT="${WORKSPACE}/build"
export SWIFT_INSTALLABLE_PACKAGE="${WORKSPACE}/${ARCHIVE}"
export SWIFT_INSTALL_DIR="${WORKSPACE}/swift-nightly-install"

umask 0022

"${WORKSPACE}/swift/utils/build-script" --preset="buildbot_linux_1510" install_destdir="${SWIFT_INSTALL_DIR}" installable_package="${SWIFT_INSTALLABLE_PACKAGE}" -- --lldb-extra-cmake-args="-DLLDB_EXPORT_ALL_SYMBOLS=1"

export PACKAGE_YML="${WORKSPACE}/package.yml"
echo "YEAR:${YEAR}" > "${PACKAGE_YML}"
echo "MONTH:${MONTH}" >> "${PACKAGE_YML}"
echo "DAY:${DAY}" >> "${PACKAGE_YML}"
echo "TOOLCHAIN_VERSION:${TOOLCHAIN_VERSION}" >> "${PACKAGE_YML}"
echo "ARCHIVE_DIR:${ARCHIVE_DIR}" >> "${PACKAGE_YML}"

for gitdir in `find ./ -name .git`;
    do
        workdir=${gitdir%/*};
        echo;
        echo $workdir;
        sha1="$(git --git-dir=$gitdir --work-tree=$workdir log --pretty=format:'%h' -n 1)";
        workdir="$(echo $workdir | sed 's/.\/\///g' |  tr '-' '_' )"
        echo "${workdir}: ${sha1}" >> "${PACKAGE_YML}"
    done

cat "${PACKAGE_YML}"
